DataRegistry

Trait DataRegistry 

pub trait DataRegistry:
    AzBuf
    + PartialEq
    + PartialOrd
    + Ord
    + Copy
    + Hash {
    type Key: DataRegistryKey;

    const NAME: &'static str;

    // Required methods
    fn protocol_id(&self) -> u32;
    fn new_raw(id: u32) -> Self;
}
A registry which has its values decided by the server in the ClientboundRegistryData packet.

These can be resolved into their actual values with ResolvableDataRegistry from azalea-core.

Required Associated Constants

const NAME: &'static str

Required Associated Types

Required Methods

fn protocol_id(&self) -> u32

fn new_raw(id: u32) -> Self

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl DataRegistry for BannerPatternKind

Source

const NAME: &'static str = "banner_pattern"

Source

type Key = BannerPatternKindKey

Source

impl DataRegistry for Biome

Source

const NAME: &'static str = "worldgen/biome"

Source

type Key = BiomeKey

Source

impl DataRegistry for CatSoundVariant

Source

const NAME: &'static str = "cat_sound_variant"

Source

type Key = CatSoundVariantKey

Source

impl DataRegistry for CatVariant

Source

const NAME: &'static str = "cat_variant"

Source

type Key = CatVariantKey

Source

impl DataRegistry for ChatKind

Source

const NAME: &'static str = "chat_type"

Source

type Key = ChatKindKey

Source

impl DataRegistry for ChickenSoundVariant

Source

const NAME: &'static str = "chicken_sound_variant"

Source

type Key = ChickenSoundVariantKey

Source

impl DataRegistry for ChickenVariant

Source

const NAME: &'static str = "chicken_variant"

Source

type Key = ChickenVariantKey

Source

impl DataRegistry for CowSoundVariant

Source

const NAME: &'static str = "cow_sound_variant"

Source

type Key = CowSoundVariantKey

Source

impl DataRegistry for CowVariant

Source

const NAME: &'static str = "cow_variant"

Source

type Key = CowVariantKey

Source

impl DataRegistry for DamageKind

Source

const NAME: &'static str = "damage_type"

Source

type Key = DamageKindKey

Source

impl DataRegistry for Dialog

Source

const NAME: &'static str = "dialog"

Source

type Key = DialogKey

Source

impl DataRegistry for DimensionKind

Source

const NAME: &'static str = "dimension_type"

Source

type Key = DimensionKindKey

Source

impl DataRegistry for Enchantment

Source

const NAME: &'static str = "enchantment"

Source

type Key = EnchantmentKey

Source

impl DataRegistry for EnchantmentProvider

Source

const NAME: &'static str = "enchantment_provider"

Source

type Key = EnchantmentProviderKey

Source

impl DataRegistry for FrogVariant

Source

const NAME: &'static str = "frog_variant"

Source

type Key = FrogVariantKey

Source

impl DataRegistry for Instrument

Source

const NAME: &'static str = "instrument"

Source

type Key = InstrumentKey

Source

impl DataRegistry for JukeboxSong

Source

const NAME: &'static str = "jukebox_song"

Source

type Key = JukeboxSongKey

Source

impl DataRegistry for PaintingVariant

Source

const NAME: &'static str = "painting_variant"

Source

type Key = PaintingVariantKey

Source

impl DataRegistry for PigSoundVariant

Source

const NAME: &'static str = "pig_sound_variant"

Source

type Key = PigSoundVariantKey

Source

impl DataRegistry for PigVariant

Source

const NAME: &'static str = "pig_variant"

Source

type Key = PigVariantKey

Source

impl DataRegistry for Recipe

Source

const NAME: &'static str = "recipe"

Source

type Key = RecipeKey

Source

impl DataRegistry for TestEnvironment

Source

const NAME: &'static str = "test_environment"

Source

type Key = TestEnvironmentKey

Source

impl DataRegistry for TestInstance

Source

const NAME: &'static str = "test_instance"

Source

type Key = TestInstanceKey

Source

impl DataRegistry for Timeline

Source

const NAME: &'static str = "timeline"

Source

type Key = TimelineKey

Source

impl DataRegistry for TrimMaterial

Source

const NAME: &'static str = "trim_material"

Source

type Key = TrimMaterialKey

Source

impl DataRegistry for TrimPattern

Source

const NAME: &'static str = "trim_pattern"

Source

type Key = TrimPatternKey

Source

impl DataRegistry for WolfSoundVariant

Source

const NAME: &'static str = "wolf_sound_variant"

Source

type Key = WolfSoundVariantKey

Source

impl DataRegistry for WolfVariant

Source

const NAME: &'static str = "wolf_variant"

Source

type Key = WolfVariantKey

Source

impl DataRegistry for WorldClock

Source

const NAME: &'static str = "world_clock"

Source

type Key = WorldClockKey

Source

impl DataRegistry for ZombieNautilusVariant

Source

const NAME: &'static str = "zombie_nautilus_variant"

Source

type Key = ZombieNautilusVariantKey